"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const child_process_1 = require("child_process");
const fs = __importStar(require("fs"));
const os = __importStar(require("os"));
const path = __importStar(require("path"));
const rimraf_1 = require("rimraf");
const generator_1 = require("../generator");
describe("generator", function () {
    // This timeout is for npm install
    jest.setTimeout(300000);
    let outputDir;
    beforeEach(() => {
        outputDir = fs.mkdtempSync(`${os.tmpdir()}${path.sep}`);
        rimraf_1.rimraf.sync(outputDir);
    });
    afterEach(() => {
        rimraf_1.rimraf.sync(outputDir);
    });
    describe("minimum template", () => {
        it("should be able to create a plugin project based on the minimum template", () => __awaiter(this, void 0, void 0, function* () {
            const manifest = JSON.parse(fs.readFileSync(path.resolve(__dirname, "fixtures", "manifest.json"), "utf8"));
            yield (0, generator_1.generatePlugin)(outputDir, manifest, "ja", true, "minimum");
            // test that `npm run lint` doesn't fail
            const lintResult = (0, child_process_1.spawnSync)("npm", ["run", "lint"], {
                cwd: outputDir,
                stdio: "inherit",
                shell: true,
            });
            (0, assert_1.default)(lintResult.status === 0);
            // test that `npm run build` doesn't fail
            const buildResult = (0, child_process_1.spawnSync)("npm", ["run", "build"], {
                cwd: outputDir,
                stdio: "inherit",
                shell: true,
            });
            (0, assert_1.default)(fs.existsSync(path.resolve(outputDir, "dist", "plugin.zip")));
            (0, assert_1.default)(buildResult.status === 0);
            assert_1.default.deepStrictEqual(JSON.parse(fs.readFileSync(path.resolve(outputDir, "src", "manifest.json"), "utf8")), manifest);
            assert_1.default.deepStrictEqual(fs.readFileSync(path.resolve(outputDir, "src", "js", "desktop.js"), "utf8"), fs.readFileSync(path.resolve(__dirname, "..", "..", "templates", "minimum", "src", "js", "desktop.js"), "utf8"));
            const packageJson = JSON.parse(fs.readFileSync(path.resolve(outputDir, "package.json"), "utf8"));
            (0, assert_1.default)(packageJson.devDependencies &&
                packageJson.devDependencies["@kintone/plugin-uploader"]);
            (0, assert_1.default)(packageJson.scripts && packageJson.scripts.upload);
        }));
    });
    describe("modern template", () => {
        it("should be able to create a plugin project based on the modern template", () => __awaiter(this, void 0, void 0, function* () {
            const manifest = JSON.parse(fs.readFileSync(path.resolve(__dirname, "fixtures", "manifest.json"), "utf8"));
            yield (0, generator_1.generatePlugin)(outputDir, manifest, "ja", false, "modern");
            // test that `npm run lint` doesn't fail
            const lintResult = (0, child_process_1.spawnSync)("npm", ["run", "lint"], {
                cwd: outputDir,
                stdio: "inherit",
                shell: true,
            });
            (0, assert_1.default)(lintResult.status === 0);
            // test that `npm run build` doesn't fail
            const buildResult = (0, child_process_1.spawnSync)("npm", ["run", "build"], {
                cwd: outputDir,
                stdio: "inherit",
                shell: true,
            });
            (0, assert_1.default)(fs.existsSync(path.resolve(outputDir, "dist", "plugin.zip")));
            (0, assert_1.default)(buildResult.status === 0);
            assert_1.default.deepStrictEqual(JSON.parse(fs.readFileSync(path.resolve(outputDir, "plugin", "manifest.json"), "utf8")), manifest);
            assert_1.default.ok(fs.existsSync(path.resolve(outputDir, "plugin", "js", "desktop.js")));
        }));
    });
});
//# sourceMappingURL=generator.test.js.map