"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const template_1 = require("../template");
const baseManifest_1 = __importDefault(require("./helpers/baseManifest"));
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
const os_1 = __importDefault(require("os"));
describe("template", () => {
    describe("getTemplateType", () => {
        it("should return be minimum", () => {
            assert_1.default.strictEqual((0, template_1.getTemplateType)((0, baseManifest_1.default)()), "minimum");
        });
    });
    describe("isNecessaryFile", () => {
        it("should returns a boolean that shows whether the file should include or not", () => {
            const manifest = (0, baseManifest_1.default)();
            (0, assert_1.default)(!(0, template_1.isNecessaryFile)(manifest, "webpack.entry.json"));
            (0, assert_1.default)(!(0, template_1.isNecessaryFile)(manifest, "with-plugin-uploader.json"));
            (0, assert_1.default)(!(0, template_1.isNecessaryFile)(manifest, "js/mobile.js"));
            (0, assert_1.default)(!(0, template_1.isNecessaryFile)(manifest, "js/config.js"));
            (0, assert_1.default)((0, template_1.isNecessaryFile)(manifest, "js/other.js"));
            (0, assert_1.default)((0, template_1.isNecessaryFile)(Object.assign(Object.assign({}, manifest), { mobile: {} }), "js/mobile.js"));
            (0, assert_1.default)((0, template_1.isNecessaryFile)(Object.assign(Object.assign({}, manifest), { config: {} }), "js/config.js"));
        });
    });
    describe("processTemplateFile", () => {
        let destDir;
        const manifest = (0, baseManifest_1.default)();
        beforeEach(() => __awaiter(void 0, void 0, void 0, function* () {
            destDir = yield fs_1.promises.mkdtemp(path_1.default.join(os_1.default.tmpdir(), "kintone-create-plugin-"));
        }));
        const patterns = [
            { template: "minimum", enablePluginUploader: false },
            { template: "minimum", enablePluginUploader: true },
            { template: "modern", enablePluginUploader: false },
            { template: "modern", enablePluginUploader: true },
        ];
        it.each(patterns)("should convert package.json correctly (template: $template, enablePluginUploader: $enablePluginUploader)", (_a) => __awaiter(void 0, [_a], void 0, function* ({ template, enablePluginUploader }) {
            const srcDir = path_1.default.resolve(__dirname, "..", "..", "templates", template);
            yield (0, template_1.processTemplateFile)(path_1.default.resolve(srcDir, "package.json"), srcDir, destDir, manifest, enablePluginUploader);
            const packageJson = JSON.parse(yield fs_1.promises.readFile(path_1.default.resolve(destDir, "package.json"), "utf8"));
            (0, assert_1.default)(packageJson.name);
            (0, assert_1.default)(packageJson.version);
            (0, assert_1.default)(packageJson.scripts);
            (0, assert_1.default)(packageJson.devDependencies);
            if (enablePluginUploader) {
                (0, assert_1.default)(packageJson.scripts.upload);
                (0, assert_1.default)(packageJson.devDependencies["@kintone/plugin-uploader"]);
            }
        }));
        it.each(patterns)("should convert template file correctly (template: $template, enablePluginUploader: $enablePluginUploader)", (_a) => __awaiter(void 0, [_a], void 0, function* ({ template, enablePluginUploader }) {
            const srcDir = path_1.default.resolve(__dirname, "..", "..", "templates", template);
            const templateFile = template === "modern"
                ? path_1.default.resolve(srcDir, "plugin", "html", "config.html.tmpl")
                : path_1.default.resolve(srcDir, "src", "html", "config.html.tmpl");
            yield (0, template_1.processTemplateFile)(templateFile, srcDir, destDir, manifest, enablePluginUploader);
            const destFile = template === "modern"
                ? path_1.default.resolve(destDir, "plugin", "html", "config.html")
                : path_1.default.resolve(destDir, "src", "html", "config.html");
            (0, assert_1.default)(yield fs_1.promises.stat(destFile));
        }));
        it.each(patterns)("should copy normal file correctly (template: $template, enablePluginUploader: $enablePluginUploader)", (_a) => __awaiter(void 0, [_a], void 0, function* ({ template, enablePluginUploader }) {
            const srcDir = path_1.default.resolve(__dirname, "..", "..", "templates", template);
            const templateFile = path_1.default.resolve(srcDir, ".gitignore");
            yield (0, template_1.processTemplateFile)(templateFile, srcDir, destDir, manifest, enablePluginUploader);
            (0, assert_1.default)(yield fs_1.promises.stat(path_1.default.resolve(destDir, ".gitignore")));
        }));
        it("should convert webpack.config.js correctly with modern template", () => __awaiter(void 0, void 0, void 0, function* () {
            const srcDir = path_1.default.resolve(__dirname, "..", "..", "templates", "modern");
            yield (0, template_1.processTemplateFile)(path_1.default.resolve(srcDir, "webpack.config.template.js"), srcDir, destDir, manifest, false);
            const destFile = path_1.default.resolve(destDir, "webpack.config.js");
            (0, assert_1.default)(yield fs_1.promises.stat(destFile));
        }));
    });
});
//# sourceMappingURL=template.test.js.map