"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk = require("chalk");
const fs = __importStar(require("fs"));
const rimraf_1 = require("rimraf");
const generator_1 = require("./generator");
const logger_1 = require("./logger");
const manifest_1 = require("./manifest");
const messages_1 = require("./messages");
const qa_1 = require("./qa");
/**
 * Verify whether the output directory is valid
 * @param outputDirectory
 * @param lang
 */
const verifyOutputDirectory = (outputDirectory, lang) => {
    if (fs.existsSync(outputDirectory)) {
        throw new Error(`${outputDirectory} ${(0, messages_1.getMessage)(lang, "Error_alreadyExists")}`);
    }
};
const getSuccessCreatedPluginMessage = (manifest, outputDir, enablePluginUploader, lang) => {
    const m = (0, messages_1.getBoundMessage)(lang);
    return `

Success! Created ${manifest.name.en} at ${outputDir}

${chalk.cyan("npm start")}

  ${m("npmStart")}
  ${enablePluginUploader ? m("npmStartWithPluginUploader") : ""}

${chalk.cyan("npm run build")}

  ${m("npmBuild")}

${chalk.cyan("npm run lint")}

  ${m("npmLint")}

${m("nextAction")}
${enablePluginUploader ? m("howToUsePluginUploader") : ""}

  cd ${outputDir}
  npm start

${m("lastMessage")}
${m("developerSite")}

      `;
};
/**
 * Run create-kintone-plugin script
 * @param outputDir
 * @param lang
 * @param templateType
 */
const run = (outputDir, lang, templateType) => {
    const m = (0, messages_1.getBoundMessage)(lang);
    verifyOutputDirectory(outputDir, lang);
    (0, logger_1.printLog)(`

  ${m("introduction")}

  `);
    (0, qa_1.runPrompt)(m, outputDir, lang)
        .then((answers) => __awaiter(void 0, void 0, void 0, function* () {
        const manifest = (0, manifest_1.buildManifest)(answers, templateType);
        yield (0, generator_1.generatePlugin)(outputDir, manifest, lang, answers.enablePluginUploader, templateType);
        return [manifest, answers.enablePluginUploader];
    }))
        .then(([manifest, enablePluginUploader]) => {
        (0, logger_1.printLog)(getSuccessCreatedPluginMessage(manifest, outputDir, enablePluginUploader, lang));
    })
        .catch((error) => {
        (0, rimraf_1.rimraf)(outputDir, { glob: true })
            .then(() => {
            (0, logger_1.printError)(m("Error_cannotCreatePlugin"), error.message);
        })
            .finally(() => {
            // eslint-disable-next-line n/no-process-exit
            process.exit(1);
        });
    });
};
module.exports = run;
module.exports.default = run;
//# sourceMappingURL=index.js.map