"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.processTemplateFile = exports.isNecessaryFile = exports.getTemplateType = exports.isValidTemplateType = exports.SUPPORT_TEMPLATE_TYPE = void 0;
const fs = __importStar(require("fs"));
const _ = __importStar(require("lodash"));
const path = __importStar(require("path"));
const sort_package_json_1 = __importDefault(require("sort-package-json"));
const standalone_1 = require("prettier/standalone");
const prettierPluginTypescript = __importStar(require("prettier/plugins/typescript"));
const prettierPluginEstree = __importStar(require("prettier/plugins/estree"));
exports.SUPPORT_TEMPLATE_TYPE = ["minimum", "modern"];
const isValidTemplateType = (templateType) => {
    return exports.SUPPORT_TEMPLATE_TYPE.indexOf(templateType) !== -1;
};
exports.isValidTemplateType = isValidTemplateType;
/**
 * Return a template type corresponding to the manifest
 * @param manifest
 */
const getTemplateType = (manifest) => {
    // We don't have any other template types
    return "minimum";
};
exports.getTemplateType = getTemplateType;
/**
 * return `true` if `file` is necessary.
 * @param manifest
 * @param file
 */
const isNecessaryFile = (manifest, file) => {
    const excludedFiles = ["with-plugin-uploader.json", "webpack.entry.json"];
    const isExcludedFile = excludedFiles.some((excludeFile) => path.basename(file) === excludeFile);
    if (isExcludedFile) {
        return false;
    }
    if (/mobile\..+/.test(file)) {
        return !!manifest.mobile;
    }
    if (/config\..+/.test(file)) {
        return !!manifest.config;
    }
    return true;
};
exports.isNecessaryFile = isNecessaryFile;
/**
 * Process a template file
 * @param filePath
 * @param srcDir
 * @param destDir
 * @param manifest
 * @param enablePluginUploader
 */
const processTemplateFile = (filePath, srcDir, destDir, manifest, enablePluginUploader) => __awaiter(void 0, void 0, void 0, function* () {
    const destFilePath = path.join(destDir, path.relative(srcDir, filePath));
    if (path.basename(filePath).endsWith(".tmpl")) {
        const src = fs.readFileSync(filePath, "utf-8");
        const destPath = path.join(path.dirname(destFilePath), path.basename(destFilePath, ".tmpl"));
        fs.mkdirSync(path.dirname(destPath), { recursive: true });
        fs.writeFileSync(destPath, _.template(src)(Object.assign({}, manifest, {
            enablePluginUploader,
            // It's a function to remove whitespaces for pacakge.json's name field
            normalizePackageName: (name) => name.replace(/\s/g, "-"),
        })));
    }
    else if (path.resolve(filePath) === path.resolve(srcDir, "package.json")) {
        const packageJson = JSON.parse(fs.readFileSync(filePath, "utf-8"));
        packageJson.name = manifest.name.en.replace(/\s/g, "-");
        if (enablePluginUploader) {
            const withPluginUploaderJson = JSON.parse(fs.readFileSync(path.join(srcDir, "with-plugin-uploader.json"), "utf-8"));
            if (withPluginUploaderJson.scripts) {
                packageJson.scripts = Object.assign(Object.assign({}, packageJson.scripts), withPluginUploaderJson.scripts);
            }
            if (withPluginUploaderJson.dependencies) {
                packageJson.dependencies = Object.assign(Object.assign({}, packageJson.dependencies), withPluginUploaderJson.dependencies);
            }
            if (withPluginUploaderJson.devDependencies) {
                packageJson.devDependencies = Object.assign(Object.assign({}, packageJson.devDependencies), withPluginUploaderJson.devDependencies);
            }
        }
        const sortedPackageJson = (0, sort_package_json_1.default)(JSON.stringify(packageJson, null, 2));
        fs.writeFileSync(destFilePath, sortedPackageJson);
    }
    else if (path.resolve(filePath) ===
        path.resolve(srcDir, "webpack.config.template.js")) {
        const webpackEntryJson = JSON.parse(fs.readFileSync(path.join(srcDir, "webpack.entry.json"), "utf-8"));
        const webpackEntry = manifest.mobile
            ? webpackEntryJson.mobile
            : webpackEntryJson.default;
        const entries = [];
        for (const [key, value] of Object.entries(webpackEntry)) {
            const entryStr = `${key}: "${value}"`;
            entries.push(entryStr);
        }
        const entriesStr = `{${entries.join(",")}}`;
        let webpackConfigContent = fs.readFileSync(filePath, "utf-8");
        webpackConfigContent = webpackConfigContent.replace(/'%%placeholder_webpack_entry%%'/, entriesStr);
        const prettySource = yield (0, standalone_1.format)(webpackConfigContent, {
            parser: "typescript",
            plugins: [prettierPluginTypescript, prettierPluginEstree],
        });
        const destPath = path.join(path.dirname(destFilePath), "webpack.config.js");
        fs.writeFileSync(destPath, prettySource);
    }
    else if (fs.statSync(filePath).isDirectory()) {
        fs.mkdirSync(destFilePath);
    }
    else {
        // fs.copyFileSync is only available <= v8.5.0
        // fs.copyFileSync(filePath, destFilePath);
        fs.writeFileSync(destFilePath, fs.readFileSync(filePath));
    }
});
exports.processTemplateFile = processTemplateFile;
//# sourceMappingURL=template.js.map